"""Calculations for the primordial Universe."""

from primpy.__version__ import __version__

__author__ = 'Lukas Hergt'
__credits__ = ['Lukas Hergt', 'Will Handley', 'Mike Hobson', 'Anthony Lasenby']
__email__ = 'lh561@mrao.cam.ac.uk'
__version__ = __version__
__all__ = ['time', 'solver', 'units', 'parameters', 'potentials', 'events']
